==> thunderbird-1.5rc1.tar.gz: content/messenger/preferences/general.js <==
//@line 36 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/mail/components/preferences/general.js"

var gGeneralPane = {
  mPane: null,
  mSound: null,

  init: function ()
  {
    this.mPane = document.getElementById("paneGeneral"); 

//@line 50 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/mail/components/preferences/general.js"

//@line 52 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/mail/components/preferences/general.js"
  // first check whether nsIMapiRegistry is available.  if it's not,
  // hide the whole default mail/news app section.
  var mapiReg;
  try {
    mapiReg = Components.classes["@mozilla.org/mapiregistry;1"].getService(Components.interfaces.nsIMapiRegistry);
  } catch (e) {}
  
  if (!mapiReg) 
    document.getElementById("defaultClientBox").hidden = true;
//@line 62 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/mail/components/preferences/general.js"
  },

//@line 111 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/mail/components/preferences/general.js"
  startPageCheck: function() 
  {
    document.getElementById("mailnewsStartPageUrl").disabled = !document.getElementById("mailnewsStartPageEnabled").checked;
  },
  
  setHomePageToDefaultPage: function ()
  {
    var prefService = Components.classes["@mozilla.org/preferences-service;1"]
                                .getService(Components.interfaces.nsIPrefService);
    var pref = prefService.getDefaultBranch(null);
    var url = pref.getComplexValue("mailnews.start_page.url",
                                   Components.interfaces.nsIPrefLocalizedString).data;
    var startPageUrlField = document.getElementById("mailnewsStartPageUrl");
    startPageUrlField.value = url;
    
    this.mPane.userChangedValue(startPageUrlField);
  },

//@line 130 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/mail/components/preferences/general.js"
  openDefaultClientDialog: function () 
  {
    document.documentElement
            .openSubDialog("chrome://messenger/content/preferences/defaultClient.xul",
                           "", null);
  },
//@line 137 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/mail/components/preferences/general.js"

  showConnections: function ()
  {
    document.documentElement
            .openSubDialog("chrome://messenger/content/preferences/connection.xul",
                           "", null);
  },

  showAdvancedSound: function()
  {
    document.documentElement
            .openSubDialog("chrome://messenger/content/preferences/notifications.xul",
                            "", null);
  }
};

==> thunderbird-1.5.0.7.tar.gz: content/messenger/preferences/general.js <==
//@line 36 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/mail/components/preferences/general.js"

var gGeneralPane = {
  mPane: null,
  mSound: null,

  init: function ()
  {
    this.mPane = document.getElementById("paneGeneral"); 

//@line 50 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/mail/components/preferences/general.js"

//@line 52 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/mail/components/preferences/general.js"
  // first check whether nsIMapiRegistry is available.  if it's not,
  // hide the whole default mail/news app section.
  var mapiReg;
  try {
    mapiReg = Components.classes["@mozilla.org/mapiregistry;1"].getService(Components.interfaces.nsIMapiRegistry);
  } catch (e) {}
  
  if (!mapiReg) 
    document.getElementById("defaultClientBox").hidden = true;
//@line 62 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/mail/components/preferences/general.js"
  },

//@line 111 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/mail/components/preferences/general.js"
  startPageCheck: function() 
  {
    document.getElementById("mailnewsStartPageUrl").disabled = !document.getElementById("mailnewsStartPageEnabled").checked;
  },
  
  setHomePageToDefaultPage: function ()
  {
    var prefService = Components.classes["@mozilla.org/preferences-service;1"]
                                .getService(Components.interfaces.nsIPrefService);
    var pref = prefService.getDefaultBranch(null);
    var url = pref.getComplexValue("mailnews.start_page.url",
                                   Components.interfaces.nsIPrefLocalizedString).data;
    var startPageUrlField = document.getElementById("mailnewsStartPageUrl");
    startPageUrlField.value = url;
    
    this.mPane.userChangedValue(startPageUrlField);
  },

//@line 130 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/mail/components/preferences/general.js"
  openDefaultClientDialog: function () 
  {
    document.documentElement
            .openSubDialog("chrome://messenger/content/preferences/defaultClient.xul",
                           "", null);
  },
//@line 137 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/mail/components/preferences/general.js"

  showConnections: function ()
  {
    document.documentElement
            .openSubDialog("chrome://messenger/content/preferences/connection.xul",
                           "", null);
  },

  showAdvancedSound: function()
  {
    document.documentElement
            .openSubDialog("chrome://messenger/content/preferences/notifications.xul",
                            "", null);
  }
};
